#include <utils.h>

#include "diskview.h"
#include "diskview.moc"

#define i18n(x) x

DiskViewItem::DiskViewItem( QListView *parent, const QString &diskName, const QString &fstype,
			    const QString &sizeStr, const QString &startStr, const QString &endStr )
  : QListViewItem( parent, diskName, fstype, sizeStr, startStr, endStr ),
    part( 0 )
{

}

DiskViewItem::DiskViewItem( QListViewItem *parent, const QString &diskName, const QString &fstype,
			    const QString &sizeStr, const QString &startStr, const QString &endStr )
  : QListViewItem( parent, diskName, fstype, sizeStr, startStr, endStr ),
    part( 0 )
{

}

DiskView::DiskView( QWidget *parent, const char *name )
  : QListView( parent, name )
{
  setRootIsDecorated( true );
  setAllColumnsShowFocus( true );

  addColumn( i18n( "Partition" ) );
  setColumnAlignment( 0, AlignCenter );
  addColumn( i18n( "Type" ) );
  addColumn( i18n( "Size (Mb)" ) );
  addColumn( i18n( "Start" ) );
  setColumnAlignment( 3, AlignRight );
  addColumn( i18n( "End" ) );
  setColumnAlignment( 4, AlignRight );
}

DiskView::~DiskView()
{
}

void DiskView::setDisk( PedDisk *disk )
{
  clear();

  for ( PedPartition *part = ped_disk_next_partition (disk, NULL);
	part;
	part = ped_disk_next_partition (disk, part) ) {
    // Don't for show meta data or free space
    if ( !ped_partition_is_active( part ) )
      continue;
    if ( part->type & PED_PARTITION_LOGICAL )
      continue;

    addPartition( disk, part );
  }

  connect( this, SIGNAL( selectionChanged( QListViewItem * ) ),
	   SLOT( selectionChanged( QListViewItem * ) ) );
}

void DiskView::addPartition( PedDisk *disk, PedPartition *part )
{
  QString diskName = disk->dev->path;
  if ( diskName.startsWith( "/dev/" ) )
    diskName = diskName.mid( 5 );
  QString partNum;
  diskName += partNum.setNum( part->num );

  QString fstype = part->fs_type ? part->fs_type->name : "";
  if ( (!part->fs_type) && (part->type == PED_PARTITION_EXTENDED) )
    fstype = "Extended";

  long double length = ( part->geom.length * (disk->dev->sector_size / 1024.0) ) /1024.0;
  QString sizeStr = Utils::toString( length );
  QString startStr = Utils::toString( part->geom.start );
  QString endStr = Utils::toString( part->geom.end );

  // Not supported by DOS-style partition tables
  //  const char *nameStr = ped_partition_get_name( part );
  //  QString name( nameStr ? nameStr : "" );

  DiskViewItem *item = new DiskViewItem( this, diskName, fstype, sizeStr, startStr, endStr );
  item->part = part;

  if ( part->type != PED_PARTITION_EXTENDED )
    return;
  
  for ( PedPartition *epart = part->part_list;
	epart;
	epart = epart->next ) {
    // Don't for show meta data or free space
    if ( !ped_partition_is_active( epart ) )
      continue;
    if ( !epart->type & PED_PARTITION_LOGICAL )
      return;

    addLogicalPartition( item, disk, epart );
  }
}

void DiskView::addLogicalPartition( QListViewItem *parent, PedDisk *disk, PedPartition *part )
{
  QString diskName = disk->dev->path;
  if ( diskName.startsWith( "/dev/" ) )
    diskName = diskName.mid( 5 );
  QString partNum;
  diskName += partNum.setNum( part->num );

  QString fstype = part->fs_type ? part->fs_type->name : "";
  if ( (!part->fs_type) && (part->type == PED_PARTITION_EXTENDED) )
    fstype = "Extended";

  long double length = ( part->geom.length * (disk->dev->sector_size / 1024.0) ) /1024.0;
  QString sizeStr = Utils::toString( length );
  QString startStr = Utils::toString( part->geom.start );
  QString endStr = Utils::toString( part->geom.end );

  // Not supported by DOS-style partition tables
  //  const char *nameStr = ped_partition_get_name( part );
  //  QString name( nameStr ? nameStr : "" );

  DiskViewItem *item = new DiskViewItem( parent, diskName, fstype, sizeStr, startStr, endStr );
  item->part = part;
  parent->setOpen( true );
}

void DiskView::selectionChanged( QListViewItem *i )
{
  DiskViewItem *di = static_cast<DiskViewItem *>(i);
  emit partitionSelected( di->part );
}
