#include "diskview.h"
#include "drivelistview.h"
#include "drivelistview.moc"

DriveListView::DriveListView( QWidget *parent, const char *name )
  : QListView( parent, name )
{
  setAllColumnsShowFocus( true );
  addColumn( "Device" );

  buildView();

  connect( this, SIGNAL( selectionChanged( QListViewItem * ) ),
	   this, SLOT( itemSelected( QListViewItem * ) ) );
  connect( this, SIGNAL( onItem( QListViewItem * ) ),
	   this, SLOT( onItem( QListViewItem * ) ) );
  connect( this, SIGNAL( onViewport() ),
	   this, SLOT( onViewport() ) );
}

DriveListView::~DriveListView()
{

}

void DriveListView::buildView()
{
  QListViewItem *ideRoot = new QListViewItem( this, "IDE Disks" );
  QListViewItem *scsiRoot = new QListViewItem( this, "SCSI Disks" );
  QListViewItem *dacRoot = new QListViewItem( this, "DAC960 Disks" );
  QListViewItem *unknownRoot = new QListViewItem( this, "Unknown Disks" );

  ped_device_probe_all();
  PedDevice *dev = ped_device_get_next( 0 );
  while( dev ) {
    if ( dev->type == PED_DEVICE_IDE )
      addDevice( dev, ideRoot );
    else if ( dev->type == PED_DEVICE_SCSI )
      addDevice( dev, scsiRoot );
    else if ( dev->type == PED_DEVICE_DAC960 )
      addDevice( dev, dacRoot );
    else
      addDevice( dev, unknownRoot );

    dev = ped_device_get_next( dev );
  };

#if 0
  if ( ideRoot->childCount() )
    ideRoot->setOpen( true );
  else
    delete ideRoot;

  if ( scsiRoot->childCount() )
    scsiRoot->setOpen( true );
  else
    delete scsiRoot;

  if ( dacRoot->childCount() )
    dacRoot->setOpen( true );
  else
    delete dacRoot;

  if ( unknownRoot->childCount() )
    unknownRoot->setOpen( true );
  else
    delete unknownRoot;
#endif
}

void DriveListView::addDevice( PedDevice *dev, QListViewItem *parent )
{
  new QListViewItem( parent, dev->path );
}

void DriveListView::itemSelected( QListViewItem *item )
{
  if ( item->parent() ) {
    PedDevice *dev = ped_device_get( item->text(0) );
    if (dev)
      emit selected( dev );
  }
}

void DriveListView::onItem( QListViewItem *item )
{
  if ( item->parent() ) {
    PedDevice *dev = ped_device_get( item->text(0) );
    emit onItem( dev );
  }
  else {
    QListViewItem *item = selectedItem();
    if ( item ) {
      PedDevice *dev = ped_device_get( item->text(0) );
      emit onItem( dev );
    }
    else
      emit onItem( static_cast<PedDevice *>(0) );
  }
}

void DriveListView::onViewport()
{
  QListViewItem *item = selectedItem();
  if ( item && item->parent() ) {
    PedDevice *dev = ped_device_get( item->text(0) );
    emit onItem( dev );
  }
  else
    emit onItem( static_cast<PedDevice *>(0) );
}
