/***************************************************************************
                          kpartedview.cpp  -  description
                             -------------------
    begin                : Fri Jul 13 17:32:54 BST 2001
    copyright            : (C) 2001 by Richard Moore
    email                : rich@kde.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qlabel.h>
#include <qlayout.h>
#include <qlistview.h>
#include <qmessagebox.h>
#include <qpixmap.h>
#include <qsplitter.h>
#include <qvbox.h>

#include "navview.h"
#include "deviceview.h"

#include "kpartedview.h"

#include "hdd_unmount.xpm"

#define i18n(x) x

QWidget *KPartEdView::dlgParent = 0;

PedExceptionOption KPartEdView::exHandler( PedException *ex )
{
   qWarning( "kparted: Exception handler started (%x)", ex );
   qWarning( "kparted: Exception type: %u, '%s'", ex->type, ex->message );
   qWarning( "kparted: Exception options: %u", ex->options );

   QMessageBox::Icon icon;
   QString caption;
   switch ( ex->type ) {
   case PED_EXCEPTION_INFORMATION:
     caption = i18n( "KPartEd - Information" );
     icon = QMessageBox::Information;
     break;
   case PED_EXCEPTION_WARNING:
     caption = i18n( "KPartEd - Warning" );
     icon = QMessageBox::Warning;
     break;
   case PED_EXCEPTION_ERROR:
     caption = i18n( "KPartEd - Error" );
     icon = QMessageBox::Critical;
     break;
   case PED_EXCEPTION_FATAL:
     caption = i18n( "KPartEd - Fatal Error" );
     icon = QMessageBox::Critical;
     break;
   case PED_EXCEPTION_BUG:
     caption = i18n( "KPartEd - Parted Bug" );
     icon = QMessageBox::Critical;
     break;
   case PED_EXCEPTION_NO_FEATURE:
     caption = i18n( "KPartEd - Unknown Feature" );
     icon = QMessageBox::Critical;
     break;
   default:
     caption = i18n( "KPartEd - Unknown Exception Type" );
     icon = QMessageBox::Critical;
     break;
   }

   QString msg( "<qt>%1</qt>" );
   msg = msg.arg( ex->message );

   QMessageBox box( dlgParent ); // TODO: Buttons, parent...
   box.setCaption( caption );
   box.setText( msg );
   box.setIcon( icon ); 
   box.exec();

   PedExceptionOption result = PED_EXCEPTION_UNHANDLED;
   qWarning( "kparted: Exception handler returning %u", result );

   return result;
}

static QString titleText( "<qt><font color=\"#ffffff\"><h1>%1</h1></font><h3>%2</h3></qt>" );

KPartEdView::KPartEdView(QWidget *parent) : QWidget(parent)
{
  dlgParent = this;
  QVBoxLayout *box = new QVBoxLayout( this, 6, 6 );

  //
  // Title Block
  //
  QHBox *titleBox = new QHBox( this );
  titleBox->setFrameStyle( QFrame::Box | QFrame::Plain );
  titleBox->setLineWidth( 2 );
  titleBox->setBackgroundColor( QColor( 0xa8, 0xa8, 0xff ) );
  titleBox->setMargin( 6 );
  titleBox->setSpacing( 6 );

  QLabel *titleIcon = new QLabel( titleBox );
  titleIcon->setBackgroundColor( QColor( 0xa8, 0xa8, 0xff ) );
  QPixmap icon( (const char **) hdd_unmount );
  titleIcon->setPixmap( icon );
  titleIcon->setFixedSize( titleIcon->sizeHint() );

  titleLabel = new QLabel( titleText.arg( i18n("KPartEd 0.1") )
			   .arg( "(c) 2001 Richard Moore, rich@kde.org" ),
			   titleBox );
  titleLabel->setBackgroundColor( QColor( 0xa8, 0xa8, 0xff ) );
  box->addWidget( titleBox );

  //
  // Work Area
  //
  QSplitter *navSplit = new QSplitter( this );
  box->addWidget( navSplit );

  ped_exception_set_handler( &exHandler );
  ped_init();

  nav = new NavView( navSplit );
  dev = new DeviceView( navSplit );

  connect( nav, SIGNAL( selected(PedDevice *) ),
	   dev, SLOT( setDevice(PedDevice *) ) );
  connect( dev, SIGNAL( setTitle( const QString &, const QString & ) ),
	   this, SLOT( setTitle( const QString &, const QString & ) ) );
  
}

KPartEdView::~KPartEdView()
{
  ped_done();
}

void KPartEdView::setTitle( const QString &title, const QString &subTitle )
{
  titleLabel->setText( titleText.arg( title ).arg( subTitle ) );
}

