#include <qgroupbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qvbox.h>

#include "drivelistview.h"
#include "utils.h"

#include "navview.h"
#include "navview.moc"

#define i18n(x) x

NavView::NavView( QWidget *parent )
  : QWidget( parent, "Navigation Frame" )
{
  QVBoxLayout *box = new QVBoxLayout( this, 6, 6 );

  //
  // Drive List
  //
  QLabel *title = new QLabel( i18n("<qt>The following drives have been detected:</qt>"),
			      this );
  box->addWidget( title );

  drives = new DriveListView( this );
  connect( drives, SIGNAL( selected(PedDevice *) ),
	   this, SIGNAL( selected(PedDevice *) ) );
  box->addWidget( drives );

  //
  // Drive Info
  //
  QVBox *titleBox = new QVBox( this );
  titleBox->setFrameStyle( QFrame::Box | QFrame::Plain );
  titleBox->setBackgroundColor( black );
  titleBox->setMargin( 2 );
  titleBox->setSpacing( 2 );

  QLabel *infoTitle = new QLabel( "<qt><center><b>Drive Info</b></center></qt>", titleBox );
  infoTitle->setBackgroundColor( QColor( 0xa8, 0xa8, 0xff ) );

  details = new QLabel( titleBox );
  displayInfo( 0 );

  box->addWidget( titleBox );

  connect( drives, SIGNAL( onItem(PedDevice *) ),
	   this, SLOT( displayInfo(PedDevice *) ) );
}

NavView::~NavView()
{

}

void NavView::displayInfo( PedDevice *dev )
{
  QString infoTemplate( "<qt bgcolor=\"#c8c8ff\">"
			"<table width=100% bgcolor=\"#c8c8ff\" cellspacing=0 cellpadding=3>%1</table>"
			"</qt>" );

  if ( !dev ) {
    QString defaultTemplate( "<tr><td bgcolor=\"#f0f0ff\">%1</td></tr>" );
    details->setText( infoTemplate.arg( defaultTemplate.arg( "<i>No Drive Selected</i>" ) ) );
    return;
  }

  QString items;
  QString itemTemplate( "<tr><th bgcolor=\"#c8c8ff\">%1</th>"
			"<td align=\"center\" width=60% bgcolor=\"#f0f0ff\">%2</td></tr>" );

  items += itemTemplate.arg( "Device:" ).arg( dev->path );
  items += itemTemplate.arg( "Model:" ).arg( dev->model );
  long double length = ( dev->length * (dev->sector_size / 1024.0) ) /1024.0;
  items += itemTemplate.arg( "Capacity (Mb):" ).arg( Utils::toString( length ) );
  items += itemTemplate.arg( "Length (sectors):" ).arg( Utils::toString( dev->length ) );
  // This is too 
  //  items += itemTemplate.arg( "Sector Size (bytes):" ).arg( dev->sector_size );

  details->setText( infoTemplate.arg(items) );
}
